@@ -10,9 +10,15 @@ my @data = DBIx::Connect->data_array('basic');
 my $app  = DBIx::AnyDBD->connect(@data, 'PApp::Hinduism');
 $PApp::SQL::DBH = $app->get_dbh;
 
-$app->create_temp('course');
+#$app->create_temp('course');
 
-#$app->insert_dept('Sanskrit and Indian Studies');
+#    my $cid = 37;
+#my $x  = $app->select_id_for_person_type('lecturer');
+#my $cl = $app->select_person($x, 'Witzel', 'Michael');
+#$app->insert_course_lecturer($cid, $cl);
+
+
+$app->insert_dept('Religion', 'http://www.bu.edu/religion/main/religionhome.html',6);
 #$app->insert_school_dept_course(
 
 #$app->insert_book_in_course_material_via_book_id_and_course_id( 15  , 27);
@@ -22,12 +28,13 @@ $app->create_temp('course');
 
 #Leonard W. J. van der Kuijp 
 
-#$app->insert_person('lecturer', 'Kuijp', 'Leonard', 'W. J. van der');
+#$app->insert_person('lecturer', 'Korom', 'Frank');
 
 #my $x = $app->next_in_sequence('course_reader___id');
 #$app->insert_course_reader('RELS 104');
 
 
+#$app->insert_school("Boston University");
 
 #$app->insert_school("Harvard University");
 #$app->insert_material_type('book');
@@ -38,16 +45,15 @@ $app->create_temp('course');
 {
     my $seq_id    = $app->select_nextval('course___id');
 #    my $seq_id    = 28;
-    my $school_id = $app->select_school_id('Harvard University');
+    my $school_id = $app->select_school_id_via_school_name('Boston University');
     $app->insert_course(
 $seq_id,
-'Intermediate Sanskrit',
-'http://www.registrar.fas.harvard.edu/Courses/SanskritandIndianStudies.html', 
+'Hinduism',
+'http://www.bu.edu/religion/courses/coursespage/courses-new.html', 
 $school_id, 
-
-''
+'Introduction to the Hindu tradition. Ritual and philosophy of the Vedas and Upanishads, yoga in the Bhagavad Gita, gods and goddesses in Hindu mythology, "popular" aspects of village and temple ritual, and problems of modernization and communalism in postcolonial India.'
 ,
-'Sanskrit 102b');
+'RN 213');
 
 
 #    my $mid  = 10;# "A Rapid Sanskrit Method" $app->select_id_from_name('Bhagavad Gita', 'book');
@@ -59,7 +65,3 @@ $school_id,
 =cut
 
 
-    my $cid = 37;
-my $x  = $app->select_id_for_person_type('lecturer');
-my $cl = $app->select_person($x, 'Witzel', 'Michael');
-$app->insert_course_lecturer($cid, $cl);
